Colorblind-reasonable palette derived from the MetBrewer Cross palette
(Blake Robert Mills). Embedded as hex values so there is no runtime
dependency on the MetBrewer package.
Usage
bread_colors(which = c("classification", "group", "cross"))Colorblind-reasonable palette derived from the MetBrewer Cross palette
(Blake Robert Mills). Embedded as hex values so there is no runtime
dependency on the MetBrewer package.
bread_colors(which = c("classification", "group", "cross"))