Skip to contents

Boxplot + jitter of the summarized region values for a single region, grouped by the first variable in the design formula.

Usage

plot_region_data(fit, region_id)

Arguments

fit

A BreadFit.

region_id

Single region ID.

Value

A ggplot2::ggplot object.