Boxplot + jitter of the summarized region values for a single region, grouped by the first variable in the design formula.
Arguments
- fit
A BreadFit.
- region_id
Single region ID.
Value
A ggplot2::ggplot object.
Boxplot + jitter of the summarized region values for a single region, grouped by the first variable in the design formula.
A BreadFit.
Single region ID.
A ggplot2::ggplot object.